#HelloCharts for Android

Charting library for Android compatible with API 8+(Android 2.2).
Works best when hardware acceleration is available so I recommend using it with API 14+(Android 4.0).
Apache License, version 2.0.

##Features

 - Line chart
 - Column chart
 - Pie chart
 - Bubble chart
 - Combo chart(columns/lines)
 - Preview charts(for column chart and line chart)
 - Zoom(pinch to zoom, double tap zoom), scroll and fling
 - Custom and auto-generated axes(most charts handles four axes: top, bottom, left, right)
 - Animations

##Screens and Demos

Code of a demo application is in hellocharts-samples directory.   
The demo app is also ready for download on the [Google Play](https://play.google.com/store/apps/details?id=lecho.lib.hellocharts.samples).  
Short video is available on [YouTube](https://www.youtube.com/watch?v=xbSBjyjH2SY).

![](screens/scr-line1.png)

![](screens/scr-tempo.png)

![](screens/scr-dependency.png)

![](screens/scr-combo.png)

![](screens/scr-column1.png)

![](screens/scr-preview-column.png)

![](screens/scr-pie1.png)

![](screens/scr-bubble1.png)

##Download and Import

###Eclipse

 - download hellocharts-library-<version>.jar from releases page and copy it into the `libs` folder of your
 application project.

 **or**

 - download/clone repository and import hellocharts-library project into your workspace: `File -> Import -> Android ->
 Existing Android Code` and select hellocharts-library directory. Right click on application project `Properties ->
 Android -> Add` and select hellocharts library project.

###Android Studio/Gradle

 - download/clone repository and import hellocharts-library as module: `File -> Import Module` and select
 hellocharts-library directory. Add dependency:
 ```groovy
     compile project(':hellocharts-library')
 ```

 **or**

 - download/clone repository and publish library artifact into your local or remote repository. Go to
 hellocharts-library directory and execute `gradle clean build publishToMavenLocal` to publish to maven local
  repository. Go to hellocharts-library directory and execute `gradle clean build publish` to publish to other
  repository configured in build.gradle(you need to modify repository url and credentials in build.gradle file). Add
  dependency:
 ```groovy
     compile 'lecho.lib.hellocharts:hellocharts-library:1.0@aar'
     compile 'com.android.support:support-v4:20+'
 ```

##Usage

Every chart view can be defined in layout xml file:

 ```xml
    <lecho.lib.hellocharts.LineChartView
        android:id="@+id/chart"
        android:layout_width="match_parent"
        android:layout_height="match_parent" />
 ```

 or created in code and added to layout later:

 ```java
    LineChartView chart = new LineChartView(context);
    layout.addView(chart);
 ```

 Use methods from *Chart classes to define chart behaviour, example methods:

 ```java
    Chart.setInteractive(boolean isInteractive);
    Chart.setZoomType(ZoomType zoomType);
    Chart.setContainerScrollEnabled(boolean isEnabled, ContainerScrollType type);
 ```

 Use methods from data models to define how chart looks like, example methods:

 ```java
    ChartData.setAxisXBottom(Axis axisX);
    ColumnChartData.setStacked(boolean isStacked);
    Line.setStrokeWidth(int strokeWidthDp);
 ```

 Every chart has its own method to set chart data and its own data model, example for line chart:

 ```java
    LineChartView chart = new LineChartView(context);

    List<PointValue> values = new ArrayList<PointValue>(numValues);
    values.add(new PointValue(0, 2));
    values.add(new PointValue(1, 4));
    values.add(new PointValue(2, 3));
    values.add(new PointValue(3, 4));

    //In most cased you can call data model methods in builder-pattern-like manner.
    Line line = new Line(values).setColor(Color.Blue).setCubic(true);
    List<Line> lines = new ArrayList<Line>(1);
    lines.add(line);

    LineChartData data = new LineChartData();
    data.setLines(lines);

    LineChartView.setLineChartData(LineChartData data);
 ```

 After the chart data has been set you can still modify its attributes but right after that you should call
 `set*ChartData()` method again to let chart recalculate and redraw data. There is also an option to use copy constructor for deep copy of
 chart data. You can safely modify copy in other threads and pass it to `set*ChartData()` method later.

 Check out hellocharts-samples project for more usage examples. I will try to update documentation soon.

#License

    Copyright 2014 Leszek Wach

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.
